from . import version

__version__ = version.version

default_app_config = "django_afip.apps.AfipConfig"
